<?php

namespace App\domain\travelport;

use Exception;
use GuzzleHttp\Exception\GuzzleException;

class AddOfferInWorkbench extends Workbench
{
    protected string $reservationId;
    protected string $catalogProductOfferingsIdentifier;
    protected array $products;

    public function execute(string $reservationId, string $catalogProductOfferingsIdentifier, array $products)
    {
        $this->reservationId = $reservationId;
        $this->catalogProductOfferingsIdentifier = $catalogProductOfferingsIdentifier;
        $this->products = $products;

        return $this->travelportPost();
    }

    protected function buildApiUrl(): string
    {
        return "https://{$this->baseURL}/{$this->apiVersion}/air/book/airoffer/reservationworkbench/{$this->reservationId}/offers/buildfromcatalogproductofferings";
    }

    protected function createPayload(): array
    {
        $productQuery = [];
        foreach ($this->products as $product) {
            $productQuery [] = [
                "CatalogProductOfferingIdentifier" => [
                    "Identifier" => [
                        "value" => $product['offerId']
                    ]
                ],
                "ProductIdentifier" => [
                    [
                        "Identifier" => [
                            "value" => $product['productId']
                        ]
                    ]
                ]
            ];
        }

        return [
            "OfferQueryBuildFromCatalogProductOfferings" => [
                "BuildFromCatalogProductOfferingsRequest" => [
                    "@type" => "BuildFromCatalogProductOfferingsRequestAir",
                    "CatalogProductOfferingsIdentifier" => [
                        "Identifier" => [
                            "value" => $this->catalogProductOfferingsIdentifier
                        ]
                    ],
                    "CatalogProductOfferingSelection" => [...$productQuery]
                ]
            ]
        ];
    }
}
